vfbLib.parsers.text.NameRecordsParser
=====================================

.. currentmodule:: vfbLib.parsers.text

.. autoclass:: NameRecordsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NameRecordsParser.__init__
      ~NameRecordsParser.parse
      ~NameRecordsParser.parse_hex
      ~NameRecordsParser.read_double
      ~NameRecordsParser.read_doubles
      ~NameRecordsParser.read_float
      ~NameRecordsParser.read_floats
      ~NameRecordsParser.read_int16
      ~NameRecordsParser.read_int32
      ~NameRecordsParser.read_int8
      ~NameRecordsParser.read_str
      ~NameRecordsParser.read_str_all
      ~NameRecordsParser.read_uint16
      ~NameRecordsParser.read_uint32
      ~NameRecordsParser.read_uint8
      ~NameRecordsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NameRecordsParser.encoding
      ~NameRecordsParser.master_count
      ~NameRecordsParser.stream
      ~NameRecordsParser.ttStemsH_count
      ~NameRecordsParser.ttStemsV_count
   
   